=======================================================================
exponot - Reference implementation of Apple/Google COVID-19 tracing API
=======================================================================

Exposure Notification based on docs of Apple/Google collaboration.

This reference implementation uses `pycryptodome <https://www.pycryptodome.org/en/latest/>`_ and `cryptography <https://cryptography.io/en/latest/>`_ libraries.

References
----------

* https://www.apple.com/covid19/contacttracing/
* https://covid19-static.cdn-apple.com/applications/covid19/current/static/contact-tracing/pdf/ExposureNotification-CryptographySpecificationv1.2.pdf
* https://www.pycryptodome.org/en/latest/
* https://cryptography.io/en/latest/
* https://github.com/DP-3T/documents
* https://sunblaze-ucb.github.io/privacy/papers/epione.pdf
